# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: g2hasher.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0eg2hasher.proto\x12\x08g2hasher"\x10\n\x0e\x44\x65stroyRequest"\x11\n\x0f\x44\x65stroyResponse"\x1b\n\x19\x45xportTokenLibraryRequest",\n\x1a\x45xportTokenLibraryResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"L\n\x0bInitRequest\x12\x12\n\nmoduleName\x18\x01 \x01(\t\x12\x11\n\tiniParams\x18\x02 \x01(\t\x12\x16\n\x0everboseLogging\x18\x03 \x01(\x03"\x0e\n\x0cInitResponse"j\n\x15InitWithConfigRequest\x12\x12\n\nmoduleName\x18\x01 \x01(\t\x12\x11\n\tiniParams\x18\x02 \x01(\t\x12\x12\n\nconfigJson\x18\x03 \x01(\t\x12\x16\n\x0everboseLogging\x18\x04 \x01(\x03"\x18\n\x16InitWithConfigResponse" \n\x0eProcessRequest\x12\x0e\n\x06record\x18\x01 \x01(\t"!\n\x0fProcessResponse\x12\x0e\n\x06result\x18\x01 \x01(\t2\x81\x03\n\x08G2Hasher\x12@\n\x07\x44\x65stroy\x12\x18.g2hasher.DestroyRequest\x1a\x19.g2hasher.DestroyResponse"\x00\x12\x61\n\x12\x45xportTokenLibrary\x12#.g2hasher.ExportTokenLibraryRequest\x1a$.g2hasher.ExportTokenLibraryResponse"\x00\x12\x37\n\x04Init\x12\x15.g2hasher.InitRequest\x1a\x16.g2hasher.InitResponse"\x00\x12U\n\x0eInitWithConfig\x12\x1f.g2hasher.InitWithConfigRequest\x1a .g2hasher.InitWithConfigResponse"\x00\x12@\n\x07Process\x12\x18.g2hasher.ProcessRequest\x1a\x19.g2hasher.ProcessResponse"\x00\x42\x62\n#com.senzing.g2.engine.grpc.G2HasherB\rG2HasherProtoP\x01Z*github.com/senzing/g2-sdk-go-grpc/g2hasherb\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "g2hasher_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b"\n#com.senzing.g2.engine.grpc.G2HasherB\rG2HasherProtoP\001Z*github.com/senzing/g2-sdk-go-grpc/g2hasher"
    _DESTROYREQUEST._serialized_start = 28
    _DESTROYREQUEST._serialized_end = 44
    _DESTROYRESPONSE._serialized_start = 46
    _DESTROYRESPONSE._serialized_end = 63
    _EXPORTTOKENLIBRARYREQUEST._serialized_start = 65
    _EXPORTTOKENLIBRARYREQUEST._serialized_end = 92
    _EXPORTTOKENLIBRARYRESPONSE._serialized_start = 94
    _EXPORTTOKENLIBRARYRESPONSE._serialized_end = 138
    _INITREQUEST._serialized_start = 140
    _INITREQUEST._serialized_end = 216
    _INITRESPONSE._serialized_start = 218
    _INITRESPONSE._serialized_end = 232
    _INITWITHCONFIGREQUEST._serialized_start = 234
    _INITWITHCONFIGREQUEST._serialized_end = 340
    _INITWITHCONFIGRESPONSE._serialized_start = 342
    _INITWITHCONFIGRESPONSE._serialized_end = 366
    _PROCESSREQUEST._serialized_start = 368
    _PROCESSREQUEST._serialized_end = 400
    _PROCESSRESPONSE._serialized_start = 402
    _PROCESSRESPONSE._serialized_end = 435
    _G2HASHER._serialized_start = 438
    _G2HASHER._serialized_end = 823
# @@protoc_insertion_point(module_scope)
