# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: g2engine.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0eg2engine.proto\x12\x08g2engine"^\n\x10\x41\x64\x64RecordRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordID\x18\x02 \x01(\t\x12\x10\n\x08jsonData\x18\x03 \x01(\t\x12\x0e\n\x06loadID\x18\x04 \x01(\t"\x13\n\x11\x41\x64\x64RecordResponse"u\n\x18\x41\x64\x64RecordWithInfoRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordID\x18\x02 \x01(\t\x12\x10\n\x08jsonData\x18\x03 \x01(\t\x12\x0e\n\x06loadID\x18\x04 \x01(\t\x12\r\n\x05\x66lags\x18\x05 \x01(\x03"+\n\x19\x41\x64\x64RecordWithInfoResponse\x12\x0e\n\x06result\x18\x01 \x01(\t",\n\x12\x43loseExportRequest\x12\x16\n\x0eresponseHandle\x18\x01 \x01(\x03"\x15\n\x13\x43loseExportResponse"\x19\n\x17\x43ountRedoRecordsRequest"*\n\x18\x43ountRedoRecordsResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03"O\n\x13\x44\x65leteRecordRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordID\x18\x02 \x01(\t\x12\x0e\n\x06loadID\x18\x03 \x01(\t"\x16\n\x14\x44\x65leteRecordResponse"f\n\x1b\x44\x65leteRecordWithInfoRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordID\x18\x02 \x01(\t\x12\x0e\n\x06loadID\x18\x03 \x01(\t\x12\r\n\x05\x66lags\x18\x04 \x01(\x03".\n\x1c\x44\x65leteRecordWithInfoResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"\x10\n\x0e\x44\x65stroyRequest"\x11\n\x0f\x44\x65stroyResponse"\x15\n\x13\x45xportConfigRequest"&\n\x14\x45xportConfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\t" \n\x1e\x45xportConfigAndConfigIDRequest"C\n\x1f\x45xportConfigAndConfigIDResponse\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\x12\x10\n\x08\x63onfigID\x18\x02 \x01(\x03"D\n\x1c\x45xportCSVEntityReportRequest\x12\x15\n\rcsvColumnList\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03"/\n\x1d\x45xportCSVEntityReportResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03".\n\x1d\x45xportJSONEntityReportRequest\x12\r\n\x05\x66lags\x18\x01 \x01(\x03"0\n\x1e\x45xportJSONEntityReportResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03"*\n\x10\x46\x65tchNextRequest\x12\x16\n\x0eresponseHandle\x18\x01 \x01(\x03"#\n\x11\x46\x65tchNextResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"K\n(FindInterestingEntitiesByEntityIDRequest\x12\x10\n\x08\x65ntityID\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03";\n)FindInterestingEntitiesByEntityIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"c\n(FindInterestingEntitiesByRecordIDRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordID\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03";\n)FindInterestingEntitiesByRecordIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"r\n\x1c\x46indNetworkByEntityIDRequest\x12\x12\n\nentityList\x18\x01 \x01(\t\x12\x11\n\tmaxDegree\x18\x02 \x01(\x03\x12\x16\n\x0e\x62uildOutDegree\x18\x03 \x01(\x03\x12\x13\n\x0bmaxEntities\x18\x04 \x01(\x03"/\n\x1d\x46indNetworkByEntityIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"\x84\x01\n\x1f\x46indNetworkByEntityID_V2Request\x12\x12\n\nentityList\x18\x01 \x01(\t\x12\x11\n\tmaxDegree\x18\x02 \x01(\x03\x12\x16\n\x0e\x62uildOutDegree\x18\x03 \x01(\x03\x12\x13\n\x0bmaxEntities\x18\x04 \x01(\x03\x12\r\n\x05\x66lags\x18\x05 \x01(\x03"2\n FindNetworkByEntityID_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t"r\n\x1c\x46indNetworkByRecordIDRequest\x12\x12\n\nrecordList\x18\x01 \x01(\t\x12\x11\n\tmaxDegree\x18\x02 \x01(\x03\x12\x16\n\x0e\x62uildOutDegree\x18\x03 \x01(\x03\x12\x13\n\x0bmaxEntities\x18\x04 \x01(\x03"/\n\x1d\x46indNetworkByRecordIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"\x84\x01\n\x1f\x46indNetworkByRecordID_V2Request\x12\x12\n\nrecordList\x18\x01 \x01(\t\x12\x11\n\tmaxDegree\x18\x02 \x01(\x03\x12\x16\n\x0e\x62uildOutDegree\x18\x03 \x01(\x03\x12\x13\n\x0bmaxEntities\x18\x04 \x01(\x03\x12\r\n\x05\x66lags\x18\x05 \x01(\x03"2\n FindNetworkByRecordID_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t"T\n\x19\x46indPathByEntityIDRequest\x12\x11\n\tentityID1\x18\x01 \x01(\x03\x12\x11\n\tentityID2\x18\x02 \x01(\x03\x12\x11\n\tmaxDegree\x18\x03 \x01(\x03",\n\x1a\x46indPathByEntityIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"f\n\x1c\x46indPathByEntityID_V2Request\x12\x11\n\tentityID1\x18\x01 \x01(\x03\x12\x11\n\tentityID2\x18\x02 \x01(\x03\x12\x11\n\tmaxDegree\x18\x03 \x01(\x03\x12\r\n\x05\x66lags\x18\x04 \x01(\x03"/\n\x1d\x46indPathByEntityID_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t"\x86\x01\n\x19\x46indPathByRecordIDRequest\x12\x17\n\x0f\x64\x61taSourceCode1\x18\x01 \x01(\t\x12\x11\n\trecordID1\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x61taSourceCode2\x18\x03 \x01(\t\x12\x11\n\trecordID2\x18\x04 \x01(\t\x12\x11\n\tmaxDegree\x18\x05 \x01(\x03",\n\x1a\x46indPathByRecordIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"\x98\x01\n\x1c\x46indPathByRecordID_V2Request\x12\x17\n\x0f\x64\x61taSourceCode1\x18\x01 \x01(\t\x12\x11\n\trecordID1\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x61taSourceCode2\x18\x03 \x01(\t\x12\x11\n\trecordID2\x18\x04 \x01(\t\x12\x11\n\tmaxDegree\x18\x05 \x01(\x03\x12\r\n\x05\x66lags\x18\x06 \x01(\x03"/\n\x1d\x46indPathByRecordID_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t"w\n"FindPathExcludingByEntityIDRequest\x12\x11\n\tentityID1\x18\x01 \x01(\x03\x12\x11\n\tentityID2\x18\x02 \x01(\x03\x12\x11\n\tmaxDegree\x18\x03 \x01(\x03\x12\x18\n\x10\x65xcludedEntities\x18\x04 \x01(\t"5\n#FindPathExcludingByEntityIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"\x89\x01\n%FindPathExcludingByEntityID_V2Request\x12\x11\n\tentityID1\x18\x01 \x01(\x03\x12\x11\n\tentityID2\x18\x02 \x01(\x03\x12\x11\n\tmaxDegree\x18\x03 \x01(\x03\x12\x18\n\x10\x65xcludedEntities\x18\x04 \x01(\t\x12\r\n\x05\x66lags\x18\x05 \x01(\x03"8\n&FindPathExcludingByEntityID_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t"\xa8\x01\n"FindPathExcludingByRecordIDRequest\x12\x17\n\x0f\x64\x61taSourceCode1\x18\x01 \x01(\t\x12\x11\n\trecordID1\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x61taSourceCode2\x18\x03 \x01(\t\x12\x11\n\trecordID2\x18\x04 \x01(\t\x12\x11\n\tmaxDegree\x18\x05 \x01(\x03\x12\x17\n\x0f\x65xcludedRecords\x18\x06 \x01(\t"5\n#FindPathExcludingByRecordIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"\xba\x01\n%FindPathExcludingByRecordID_V2Request\x12\x17\n\x0f\x64\x61taSourceCode1\x18\x01 \x01(\t\x12\x11\n\trecordID1\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x61taSourceCode2\x18\x03 \x01(\t\x12\x11\n\trecordID2\x18\x04 \x01(\t\x12\x11\n\tmaxDegree\x18\x05 \x01(\x03\x12\x17\n\x0f\x65xcludedRecords\x18\x06 \x01(\t\x12\r\n\x05\x66lags\x18\x07 \x01(\x03"8\n&FindPathExcludingByRecordID_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t"\x94\x01\n(FindPathIncludingSourceByEntityIDRequest\x12\x11\n\tentityID1\x18\x01 \x01(\x03\x12\x11\n\tentityID2\x18\x02 \x01(\x03\x12\x11\n\tmaxDegree\x18\x03 \x01(\x03\x12\x18\n\x10\x65xcludedEntities\x18\x04 \x01(\t\x12\x15\n\rrequiredDsrcs\x18\x05 \x01(\t";\n)FindPathIncludingSourceByEntityIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"\xa6\x01\n+FindPathIncludingSourceByEntityID_V2Request\x12\x11\n\tentityID1\x18\x01 \x01(\x03\x12\x11\n\tentityID2\x18\x02 \x01(\x03\x12\x11\n\tmaxDegree\x18\x03 \x01(\x03\x12\x18\n\x10\x65xcludedEntities\x18\x04 \x01(\t\x12\x15\n\rrequiredDsrcs\x18\x05 \x01(\t\x12\r\n\x05\x66lags\x18\x06 \x01(\x03">\n,FindPathIncludingSourceByEntityID_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t"\xc5\x01\n(FindPathIncludingSourceByRecordIDRequest\x12\x17\n\x0f\x64\x61taSourceCode1\x18\x01 \x01(\t\x12\x11\n\trecordID1\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x61taSourceCode2\x18\x03 \x01(\t\x12\x11\n\trecordID2\x18\x04 \x01(\t\x12\x11\n\tmaxDegree\x18\x05 \x01(\x03\x12\x17\n\x0f\x65xcludedRecords\x18\x06 \x01(\t\x12\x15\n\rrequiredDsrcs\x18\x07 \x01(\t";\n)FindPathIncludingSourceByRecordIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"\xd7\x01\n+FindPathIncludingSourceByRecordID_V2Request\x12\x17\n\x0f\x64\x61taSourceCode1\x18\x01 \x01(\t\x12\x11\n\trecordID1\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x61taSourceCode2\x18\x03 \x01(\t\x12\x11\n\trecordID2\x18\x04 \x01(\t\x12\x11\n\tmaxDegree\x18\x05 \x01(\x03\x12\x17\n\x0f\x65xcludedRecords\x18\x06 \x01(\t\x12\x15\n\rrequiredDsrcs\x18\x07 \x01(\t\x12\r\n\x05\x66lags\x18\x08 \x01(\x03">\n,FindPathIncludingSourceByRecordID_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t"\x1a\n\x18GetActiveConfigIDRequest"+\n\x19GetActiveConfigIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03".\n\x1aGetEntityByEntityIDRequest\x12\x10\n\x08\x65ntityID\x18\x01 \x01(\x03"-\n\x1bGetEntityByEntityIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"@\n\x1dGetEntityByEntityID_V2Request\x12\x10\n\x08\x65ntityID\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03"0\n\x1eGetEntityByEntityID_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t"F\n\x1aGetEntityByRecordIDRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordID\x18\x02 \x01(\t"-\n\x1bGetEntityByRecordIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"X\n\x1dGetEntityByRecordID_V2Request\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordID\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03"0\n\x1eGetEntityByRecordID_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t"<\n\x10GetRecordRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordID\x18\x02 \x01(\t"#\n\x11GetRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"N\n\x13GetRecord_V2Request\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordID\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03"&\n\x14GetRecord_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t"\x16\n\x14GetRedoRecordRequest"\'\n\x15GetRedoRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"&\n$GetRepositoryLastModifiedTimeRequest"7\n%GetRepositoryLastModifiedTimeResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03"7\n!GetVirtualEntityByRecordIDRequest\x12\x12\n\nrecordList\x18\x01 \x01(\t"4\n"GetVirtualEntityByRecordIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"I\n$GetVirtualEntityByRecordID_V2Request\x12\x12\n\nrecordList\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03"7\n%GetVirtualEntityByRecordID_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t".\n\x1aHowEntityByEntityIDRequest\x12\x10\n\x08\x65ntityID\x18\x01 \x01(\x03"-\n\x1bHowEntityByEntityIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"@\n\x1dHowEntityByEntityID_V2Request\x12\x10\n\x08\x65ntityID\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03"0\n\x1eHowEntityByEntityID_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t"L\n\x0bInitRequest\x12\x12\n\nmoduleName\x18\x01 \x01(\t\x12\x11\n\tiniParams\x18\x02 \x01(\t\x12\x16\n\x0everboseLogging\x18\x03 \x01(\x03"\x0e\n\x0cInitResponse"n\n\x17InitWithConfigIDRequest\x12\x12\n\nmoduleName\x18\x01 \x01(\t\x12\x11\n\tiniParams\x18\x02 \x01(\t\x12\x14\n\x0cinitConfigID\x18\x03 \x01(\x03\x12\x16\n\x0everboseLogging\x18\x04 \x01(\x03"\x1a\n\x18InitWithConfigIDResponse"\x14\n\x12PrimeEngineRequest"\x15\n\x13PrimeEngineResponse" \n\x0eProcessRequest\x12\x0e\n\x06record\x18\x01 \x01(\t"\x11\n\x0fProcessResponse"7\n\x16ProcessWithInfoRequest\x12\x0e\n\x06record\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03")\n\x17ProcessWithInfoResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"\x18\n\x16PurgeRepositoryRequest"\x19\n\x17PurgeRepositoryResponse":\n\x17ReevaluateEntityRequest\x12\x10\n\x08\x65ntityID\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03"\x1a\n\x18ReevaluateEntityResponse"B\n\x1fReevaluateEntityWithInfoRequest\x12\x10\n\x08\x65ntityID\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03"2\n ReevaluateEntityWithInfoResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"R\n\x17ReevaluateRecordRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordID\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03"\x1a\n\x18ReevaluateRecordResponse"Z\n\x1fReevaluateRecordWithInfoRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordID\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03"2\n ReevaluateRecordWithInfoResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"%\n\rReinitRequest\x12\x14\n\x0cinitConfigID\x18\x01 \x01(\x03"\x10\n\x0eReinitResponse"b\n\x14ReplaceRecordRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordID\x18\x02 \x01(\t\x12\x10\n\x08jsonData\x18\x03 \x01(\t\x12\x0e\n\x06loadID\x18\x04 \x01(\t"\x17\n\x15ReplaceRecordResponse"y\n\x1cReplaceRecordWithInfoRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordID\x18\x02 \x01(\t\x12\x10\n\x08jsonData\x18\x03 \x01(\t\x12\x0e\n\x06loadID\x18\x04 \x01(\t\x12\r\n\x05\x66lags\x18\x05 \x01(\x03"/\n\x1dReplaceRecordWithInfoResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"-\n\x19SearchByAttributesRequest\x12\x10\n\x08jsonData\x18\x01 \x01(\t",\n\x1aSearchByAttributesResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"?\n\x1cSearchByAttributes_V2Request\x12\x10\n\x08jsonData\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03"/\n\x1dSearchByAttributes_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t"\x0e\n\x0cStatsRequest"\x1f\n\rStatsResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"J\n"StreamExportCSVEntityReportRequest\x12\x15\n\rcsvColumnList\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03"5\n#StreamExportCSVEntityReportResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"4\n#StreamExportJSONEntityReportRequest\x12\r\n\x05\x66lags\x18\x01 \x01(\x03"6\n$StreamExportJSONEntityReportResponse\x12\x0e\n\x06result\x18\x01 \x01(\t":\n\x12WhyEntitiesRequest\x12\x11\n\tentityID1\x18\x01 \x01(\x03\x12\x11\n\tentityID2\x18\x02 \x01(\x03"%\n\x13WhyEntitiesResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"L\n\x15WhyEntities_V2Request\x12\x11\n\tentityID1\x18\x01 \x01(\x03\x12\x11\n\tentityID2\x18\x02 \x01(\x03\x12\r\n\x05\x66lags\x18\x03 \x01(\x03"(\n\x16WhyEntities_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t".\n\x1aWhyEntityByEntityIDRequest\x12\x10\n\x08\x65ntityID\x18\x01 \x01(\x03"-\n\x1bWhyEntityByEntityIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"@\n\x1dWhyEntityByEntityID_V2Request\x12\x10\n\x08\x65ntityID\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03"0\n\x1eWhyEntityByEntityID_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t"F\n\x1aWhyEntityByRecordIDRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordID\x18\x02 \x01(\t"-\n\x1bWhyEntityByRecordIDResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"X\n\x1dWhyEntityByRecordID_V2Request\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordID\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03"0\n\x1eWhyEntityByRecordID_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t"k\n\x11WhyRecordsRequest\x12\x17\n\x0f\x64\x61taSourceCode1\x18\x01 \x01(\t\x12\x11\n\trecordID1\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x61taSourceCode2\x18\x03 \x01(\t\x12\x11\n\trecordID2\x18\x04 \x01(\t"$\n\x12WhyRecordsResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"}\n\x14WhyRecords_V2Request\x12\x17\n\x0f\x64\x61taSourceCode1\x18\x01 \x01(\t\x12\x11\n\trecordID1\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x61taSourceCode2\x18\x03 \x01(\t\x12\x11\n\trecordID2\x18\x04 \x01(\t\x12\r\n\x05\x66lags\x18\x05 \x01(\x03"\'\n\x15WhyRecords_V2Response\x12\x0e\n\x06result\x18\x01 \x01(\t2\xee\x37\n\x08G2Engine\x12\x46\n\tAddRecord\x12\x1a.g2engine.AddRecordRequest\x1a\x1b.g2engine.AddRecordResponse"\x00\x12^\n\x11\x41\x64\x64RecordWithInfo\x12".g2engine.AddRecordWithInfoRequest\x1a#.g2engine.AddRecordWithInfoResponse"\x00\x12L\n\x0b\x43loseExport\x12\x1c.g2engine.CloseExportRequest\x1a\x1d.g2engine.CloseExportResponse"\x00\x12[\n\x10\x43ountRedoRecords\x12!.g2engine.CountRedoRecordsRequest\x1a".g2engine.CountRedoRecordsResponse"\x00\x12O\n\x0c\x44\x65leteRecord\x12\x1d.g2engine.DeleteRecordRequest\x1a\x1e.g2engine.DeleteRecordResponse"\x00\x12g\n\x14\x44\x65leteRecordWithInfo\x12%.g2engine.DeleteRecordWithInfoRequest\x1a&.g2engine.DeleteRecordWithInfoResponse"\x00\x12@\n\x07\x44\x65stroy\x12\x18.g2engine.DestroyRequest\x1a\x19.g2engine.DestroyResponse"\x00\x12O\n\x0c\x45xportConfig\x12\x1d.g2engine.ExportConfigRequest\x1a\x1e.g2engine.ExportConfigResponse"\x00\x12p\n\x17\x45xportConfigAndConfigID\x12(.g2engine.ExportConfigAndConfigIDRequest\x1a).g2engine.ExportConfigAndConfigIDResponse"\x00\x12j\n\x15\x45xportCSVEntityReport\x12&.g2engine.ExportCSVEntityReportRequest\x1a\'.g2engine.ExportCSVEntityReportResponse"\x00\x12m\n\x16\x45xportJSONEntityReport\x12\'.g2engine.ExportJSONEntityReportRequest\x1a(.g2engine.ExportJSONEntityReportResponse"\x00\x12\x46\n\tFetchNext\x12\x1a.g2engine.FetchNextRequest\x1a\x1b.g2engine.FetchNextResponse"\x00\x12\x8e\x01\n!FindInterestingEntitiesByEntityID\x12\x32.g2engine.FindInterestingEntitiesByEntityIDRequest\x1a\x33.g2engine.FindInterestingEntitiesByEntityIDResponse"\x00\x12\x8e\x01\n!FindInterestingEntitiesByRecordID\x12\x32.g2engine.FindInterestingEntitiesByRecordIDRequest\x1a\x33.g2engine.FindInterestingEntitiesByRecordIDResponse"\x00\x12j\n\x15\x46indNetworkByEntityID\x12&.g2engine.FindNetworkByEntityIDRequest\x1a\'.g2engine.FindNetworkByEntityIDResponse"\x00\x12s\n\x18\x46indNetworkByEntityID_V2\x12).g2engine.FindNetworkByEntityID_V2Request\x1a*.g2engine.FindNetworkByEntityID_V2Response"\x00\x12j\n\x15\x46indNetworkByRecordID\x12&.g2engine.FindNetworkByRecordIDRequest\x1a\'.g2engine.FindNetworkByRecordIDResponse"\x00\x12s\n\x18\x46indNetworkByRecordID_V2\x12).g2engine.FindNetworkByRecordID_V2Request\x1a*.g2engine.FindNetworkByRecordID_V2Response"\x00\x12\x61\n\x12\x46indPathByEntityID\x12#.g2engine.FindPathByEntityIDRequest\x1a$.g2engine.FindPathByEntityIDResponse"\x00\x12j\n\x15\x46indPathByEntityID_V2\x12&.g2engine.FindPathByEntityID_V2Request\x1a\'.g2engine.FindPathByEntityID_V2Response"\x00\x12\x61\n\x12\x46indPathByRecordID\x12#.g2engine.FindPathByRecordIDRequest\x1a$.g2engine.FindPathByRecordIDResponse"\x00\x12j\n\x15\x46indPathByRecordID_V2\x12&.g2engine.FindPathByRecordID_V2Request\x1a\'.g2engine.FindPathByRecordID_V2Response"\x00\x12|\n\x1b\x46indPathExcludingByEntityID\x12,.g2engine.FindPathExcludingByEntityIDRequest\x1a-.g2engine.FindPathExcludingByEntityIDResponse"\x00\x12\x85\x01\n\x1e\x46indPathExcludingByEntityID_V2\x12/.g2engine.FindPathExcludingByEntityID_V2Request\x1a\x30.g2engine.FindPathExcludingByEntityID_V2Response"\x00\x12|\n\x1b\x46indPathExcludingByRecordID\x12,.g2engine.FindPathExcludingByRecordIDRequest\x1a-.g2engine.FindPathExcludingByRecordIDResponse"\x00\x12\x85\x01\n\x1e\x46indPathExcludingByRecordID_V2\x12/.g2engine.FindPathExcludingByRecordID_V2Request\x1a\x30.g2engine.FindPathExcludingByRecordID_V2Response"\x00\x12\x8e\x01\n!FindPathIncludingSourceByEntityID\x12\x32.g2engine.FindPathIncludingSourceByEntityIDRequest\x1a\x33.g2engine.FindPathIncludingSourceByEntityIDResponse"\x00\x12\x97\x01\n$FindPathIncludingSourceByEntityID_V2\x12\x35.g2engine.FindPathIncludingSourceByEntityID_V2Request\x1a\x36.g2engine.FindPathIncludingSourceByEntityID_V2Response"\x00\x12\x8e\x01\n!FindPathIncludingSourceByRecordID\x12\x32.g2engine.FindPathIncludingSourceByRecordIDRequest\x1a\x33.g2engine.FindPathIncludingSourceByRecordIDResponse"\x00\x12\x97\x01\n$FindPathIncludingSourceByRecordID_V2\x12\x35.g2engine.FindPathIncludingSourceByRecordID_V2Request\x1a\x36.g2engine.FindPathIncludingSourceByRecordID_V2Response"\x00\x12^\n\x11GetActiveConfigID\x12".g2engine.GetActiveConfigIDRequest\x1a#.g2engine.GetActiveConfigIDResponse"\x00\x12\x64\n\x13GetEntityByEntityID\x12$.g2engine.GetEntityByEntityIDRequest\x1a%.g2engine.GetEntityByEntityIDResponse"\x00\x12m\n\x16GetEntityByEntityID_V2\x12\'.g2engine.GetEntityByEntityID_V2Request\x1a(.g2engine.GetEntityByEntityID_V2Response"\x00\x12\x64\n\x13GetEntityByRecordID\x12$.g2engine.GetEntityByRecordIDRequest\x1a%.g2engine.GetEntityByRecordIDResponse"\x00\x12m\n\x16GetEntityByRecordID_V2\x12\'.g2engine.GetEntityByRecordID_V2Request\x1a(.g2engine.GetEntityByRecordID_V2Response"\x00\x12\x46\n\tGetRecord\x12\x1a.g2engine.GetRecordRequest\x1a\x1b.g2engine.GetRecordResponse"\x00\x12O\n\x0cGetRecord_V2\x12\x1d.g2engine.GetRecord_V2Request\x1a\x1e.g2engine.GetRecord_V2Response"\x00\x12R\n\rGetRedoRecord\x12\x1e.g2engine.GetRedoRecordRequest\x1a\x1f.g2engine.GetRedoRecordResponse"\x00\x12\x82\x01\n\x1dGetRepositoryLastModifiedTime\x12..g2engine.GetRepositoryLastModifiedTimeRequest\x1a/.g2engine.GetRepositoryLastModifiedTimeResponse"\x00\x12y\n\x1aGetVirtualEntityByRecordID\x12+.g2engine.GetVirtualEntityByRecordIDRequest\x1a,.g2engine.GetVirtualEntityByRecordIDResponse"\x00\x12\x82\x01\n\x1dGetVirtualEntityByRecordID_V2\x12..g2engine.GetVirtualEntityByRecordID_V2Request\x1a/.g2engine.GetVirtualEntityByRecordID_V2Response"\x00\x12\x64\n\x13HowEntityByEntityID\x12$.g2engine.HowEntityByEntityIDRequest\x1a%.g2engine.HowEntityByEntityIDResponse"\x00\x12m\n\x16HowEntityByEntityID_V2\x12\'.g2engine.HowEntityByEntityID_V2Request\x1a(.g2engine.HowEntityByEntityID_V2Response"\x00\x12\x37\n\x04Init\x12\x15.g2engine.InitRequest\x1a\x16.g2engine.InitResponse"\x00\x12[\n\x10InitWithConfigID\x12!.g2engine.InitWithConfigIDRequest\x1a".g2engine.InitWithConfigIDResponse"\x00\x12L\n\x0bPrimeEngine\x12\x1c.g2engine.PrimeEngineRequest\x1a\x1d.g2engine.PrimeEngineResponse"\x00\x12@\n\x07Process\x12\x18.g2engine.ProcessRequest\x1a\x19.g2engine.ProcessResponse"\x00\x12X\n\x0fProcessWithInfo\x12 .g2engine.ProcessWithInfoRequest\x1a!.g2engine.ProcessWithInfoResponse"\x00\x12X\n\x0fPurgeRepository\x12 .g2engine.PurgeRepositoryRequest\x1a!.g2engine.PurgeRepositoryResponse"\x00\x12[\n\x10ReevaluateEntity\x12!.g2engine.ReevaluateEntityRequest\x1a".g2engine.ReevaluateEntityResponse"\x00\x12s\n\x18ReevaluateEntityWithInfo\x12).g2engine.ReevaluateEntityWithInfoRequest\x1a*.g2engine.ReevaluateEntityWithInfoResponse"\x00\x12[\n\x10ReevaluateRecord\x12!.g2engine.ReevaluateRecordRequest\x1a".g2engine.ReevaluateRecordResponse"\x00\x12s\n\x18ReevaluateRecordWithInfo\x12).g2engine.ReevaluateRecordWithInfoRequest\x1a*.g2engine.ReevaluateRecordWithInfoResponse"\x00\x12=\n\x06Reinit\x12\x17.g2engine.ReinitRequest\x1a\x18.g2engine.ReinitResponse"\x00\x12R\n\rReplaceRecord\x12\x1e.g2engine.ReplaceRecordRequest\x1a\x1f.g2engine.ReplaceRecordResponse"\x00\x12j\n\x15ReplaceRecordWithInfo\x12&.g2engine.ReplaceRecordWithInfoRequest\x1a\'.g2engine.ReplaceRecordWithInfoResponse"\x00\x12\x61\n\x12SearchByAttributes\x12#.g2engine.SearchByAttributesRequest\x1a$.g2engine.SearchByAttributesResponse"\x00\x12j\n\x15SearchByAttributes_V2\x12&.g2engine.SearchByAttributes_V2Request\x1a\'.g2engine.SearchByAttributes_V2Response"\x00\x12:\n\x05Stats\x12\x16.g2engine.StatsRequest\x1a\x17.g2engine.StatsResponse"\x00\x12~\n\x1bStreamExportCSVEntityReport\x12,.g2engine.StreamExportCSVEntityReportRequest\x1a-.g2engine.StreamExportCSVEntityReportResponse"\x00\x30\x01\x12\x81\x01\n\x1cStreamExportJSONEntityReport\x12-.g2engine.StreamExportJSONEntityReportRequest\x1a..g2engine.StreamExportJSONEntityReportResponse"\x00\x30\x01\x12L\n\x0bWhyEntities\x12\x1c.g2engine.WhyEntitiesRequest\x1a\x1d.g2engine.WhyEntitiesResponse"\x00\x12U\n\x0eWhyEntities_V2\x12\x1f.g2engine.WhyEntities_V2Request\x1a .g2engine.WhyEntities_V2Response"\x00\x12\x64\n\x13WhyEntityByEntityID\x12$.g2engine.WhyEntityByEntityIDRequest\x1a%.g2engine.WhyEntityByEntityIDResponse"\x00\x12m\n\x16WhyEntityByEntityID_V2\x12\'.g2engine.WhyEntityByEntityID_V2Request\x1a(.g2engine.WhyEntityByEntityID_V2Response"\x00\x12\x64\n\x13WhyEntityByRecordID\x12$.g2engine.WhyEntityByRecordIDRequest\x1a%.g2engine.WhyEntityByRecordIDResponse"\x00\x12m\n\x16WhyEntityByRecordID_V2\x12\'.g2engine.WhyEntityByRecordID_V2Request\x1a(.g2engine.WhyEntityByRecordID_V2Response"\x00\x12I\n\nWhyRecords\x12\x1b.g2engine.WhyRecordsRequest\x1a\x1c.g2engine.WhyRecordsResponse"\x00\x12R\n\rWhyRecords_V2\x12\x1e.g2engine.WhyRecords_V2Request\x1a\x1f.g2engine.WhyRecords_V2Response"\x00\x42\x62\n#com.senzing.g2.engine.grpc.G2EngineB\rG2EngineProtoP\x01Z*github.com/senzing/g2-sdk-go-grpc/g2engineb\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "g2engine_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b"\n#com.senzing.g2.engine.grpc.G2EngineB\rG2EngineProtoP\001Z*github.com/senzing/g2-sdk-go-grpc/g2engine"
    _ADDRECORDREQUEST._serialized_start = 28
    _ADDRECORDREQUEST._serialized_end = 122
    _ADDRECORDRESPONSE._serialized_start = 124
    _ADDRECORDRESPONSE._serialized_end = 143
    _ADDRECORDWITHINFOREQUEST._serialized_start = 145
    _ADDRECORDWITHINFOREQUEST._serialized_end = 262
    _ADDRECORDWITHINFORESPONSE._serialized_start = 264
    _ADDRECORDWITHINFORESPONSE._serialized_end = 307
    _CLOSEEXPORTREQUEST._serialized_start = 309
    _CLOSEEXPORTREQUEST._serialized_end = 353
    _CLOSEEXPORTRESPONSE._serialized_start = 355
    _CLOSEEXPORTRESPONSE._serialized_end = 376
    _COUNTREDORECORDSREQUEST._serialized_start = 378
    _COUNTREDORECORDSREQUEST._serialized_end = 403
    _COUNTREDORECORDSRESPONSE._serialized_start = 405
    _COUNTREDORECORDSRESPONSE._serialized_end = 447
    _DELETERECORDREQUEST._serialized_start = 449
    _DELETERECORDREQUEST._serialized_end = 528
    _DELETERECORDRESPONSE._serialized_start = 530
    _DELETERECORDRESPONSE._serialized_end = 552
    _DELETERECORDWITHINFOREQUEST._serialized_start = 554
    _DELETERECORDWITHINFOREQUEST._serialized_end = 656
    _DELETERECORDWITHINFORESPONSE._serialized_start = 658
    _DELETERECORDWITHINFORESPONSE._serialized_end = 704
    _DESTROYREQUEST._serialized_start = 706
    _DESTROYREQUEST._serialized_end = 722
    _DESTROYRESPONSE._serialized_start = 724
    _DESTROYRESPONSE._serialized_end = 741
    _EXPORTCONFIGREQUEST._serialized_start = 743
    _EXPORTCONFIGREQUEST._serialized_end = 764
    _EXPORTCONFIGRESPONSE._serialized_start = 766
    _EXPORTCONFIGRESPONSE._serialized_end = 804
    _EXPORTCONFIGANDCONFIGIDREQUEST._serialized_start = 806
    _EXPORTCONFIGANDCONFIGIDREQUEST._serialized_end = 838
    _EXPORTCONFIGANDCONFIGIDRESPONSE._serialized_start = 840
    _EXPORTCONFIGANDCONFIGIDRESPONSE._serialized_end = 907
    _EXPORTCSVENTITYREPORTREQUEST._serialized_start = 909
    _EXPORTCSVENTITYREPORTREQUEST._serialized_end = 977
    _EXPORTCSVENTITYREPORTRESPONSE._serialized_start = 979
    _EXPORTCSVENTITYREPORTRESPONSE._serialized_end = 1026
    _EXPORTJSONENTITYREPORTREQUEST._serialized_start = 1028
    _EXPORTJSONENTITYREPORTREQUEST._serialized_end = 1074
    _EXPORTJSONENTITYREPORTRESPONSE._serialized_start = 1076
    _EXPORTJSONENTITYREPORTRESPONSE._serialized_end = 1124
    _FETCHNEXTREQUEST._serialized_start = 1126
    _FETCHNEXTREQUEST._serialized_end = 1168
    _FETCHNEXTRESPONSE._serialized_start = 1170
    _FETCHNEXTRESPONSE._serialized_end = 1205
    _FINDINTERESTINGENTITIESBYENTITYIDREQUEST._serialized_start = 1207
    _FINDINTERESTINGENTITIESBYENTITYIDREQUEST._serialized_end = 1282
    _FINDINTERESTINGENTITIESBYENTITYIDRESPONSE._serialized_start = 1284
    _FINDINTERESTINGENTITIESBYENTITYIDRESPONSE._serialized_end = 1343
    _FINDINTERESTINGENTITIESBYRECORDIDREQUEST._serialized_start = 1345
    _FINDINTERESTINGENTITIESBYRECORDIDREQUEST._serialized_end = 1444
    _FINDINTERESTINGENTITIESBYRECORDIDRESPONSE._serialized_start = 1446
    _FINDINTERESTINGENTITIESBYRECORDIDRESPONSE._serialized_end = 1505
    _FINDNETWORKBYENTITYIDREQUEST._serialized_start = 1507
    _FINDNETWORKBYENTITYIDREQUEST._serialized_end = 1621
    _FINDNETWORKBYENTITYIDRESPONSE._serialized_start = 1623
    _FINDNETWORKBYENTITYIDRESPONSE._serialized_end = 1670
    _FINDNETWORKBYENTITYID_V2REQUEST._serialized_start = 1673
    _FINDNETWORKBYENTITYID_V2REQUEST._serialized_end = 1805
    _FINDNETWORKBYENTITYID_V2RESPONSE._serialized_start = 1807
    _FINDNETWORKBYENTITYID_V2RESPONSE._serialized_end = 1857
    _FINDNETWORKBYRECORDIDREQUEST._serialized_start = 1859
    _FINDNETWORKBYRECORDIDREQUEST._serialized_end = 1973
    _FINDNETWORKBYRECORDIDRESPONSE._serialized_start = 1975
    _FINDNETWORKBYRECORDIDRESPONSE._serialized_end = 2022
    _FINDNETWORKBYRECORDID_V2REQUEST._serialized_start = 2025
    _FINDNETWORKBYRECORDID_V2REQUEST._serialized_end = 2157
    _FINDNETWORKBYRECORDID_V2RESPONSE._serialized_start = 2159
    _FINDNETWORKBYRECORDID_V2RESPONSE._serialized_end = 2209
    _FINDPATHBYENTITYIDREQUEST._serialized_start = 2211
    _FINDPATHBYENTITYIDREQUEST._serialized_end = 2295
    _FINDPATHBYENTITYIDRESPONSE._serialized_start = 2297
    _FINDPATHBYENTITYIDRESPONSE._serialized_end = 2341
    _FINDPATHBYENTITYID_V2REQUEST._serialized_start = 2343
    _FINDPATHBYENTITYID_V2REQUEST._serialized_end = 2445
    _FINDPATHBYENTITYID_V2RESPONSE._serialized_start = 2447
    _FINDPATHBYENTITYID_V2RESPONSE._serialized_end = 2494
    _FINDPATHBYRECORDIDREQUEST._serialized_start = 2497
    _FINDPATHBYRECORDIDREQUEST._serialized_end = 2631
    _FINDPATHBYRECORDIDRESPONSE._serialized_start = 2633
    _FINDPATHBYRECORDIDRESPONSE._serialized_end = 2677
    _FINDPATHBYRECORDID_V2REQUEST._serialized_start = 2680
    _FINDPATHBYRECORDID_V2REQUEST._serialized_end = 2832
    _FINDPATHBYRECORDID_V2RESPONSE._serialized_start = 2834
    _FINDPATHBYRECORDID_V2RESPONSE._serialized_end = 2881
    _FINDPATHEXCLUDINGBYENTITYIDREQUEST._serialized_start = 2883
    _FINDPATHEXCLUDINGBYENTITYIDREQUEST._serialized_end = 3002
    _FINDPATHEXCLUDINGBYENTITYIDRESPONSE._serialized_start = 3004
    _FINDPATHEXCLUDINGBYENTITYIDRESPONSE._serialized_end = 3057
    _FINDPATHEXCLUDINGBYENTITYID_V2REQUEST._serialized_start = 3060
    _FINDPATHEXCLUDINGBYENTITYID_V2REQUEST._serialized_end = 3197
    _FINDPATHEXCLUDINGBYENTITYID_V2RESPONSE._serialized_start = 3199
    _FINDPATHEXCLUDINGBYENTITYID_V2RESPONSE._serialized_end = 3255
    _FINDPATHEXCLUDINGBYRECORDIDREQUEST._serialized_start = 3258
    _FINDPATHEXCLUDINGBYRECORDIDREQUEST._serialized_end = 3426
    _FINDPATHEXCLUDINGBYRECORDIDRESPONSE._serialized_start = 3428
    _FINDPATHEXCLUDINGBYRECORDIDRESPONSE._serialized_end = 3481
    _FINDPATHEXCLUDINGBYRECORDID_V2REQUEST._serialized_start = 3484
    _FINDPATHEXCLUDINGBYRECORDID_V2REQUEST._serialized_end = 3670
    _FINDPATHEXCLUDINGBYRECORDID_V2RESPONSE._serialized_start = 3672
    _FINDPATHEXCLUDINGBYRECORDID_V2RESPONSE._serialized_end = 3728
    _FINDPATHINCLUDINGSOURCEBYENTITYIDREQUEST._serialized_start = 3731
    _FINDPATHINCLUDINGSOURCEBYENTITYIDREQUEST._serialized_end = 3879
    _FINDPATHINCLUDINGSOURCEBYENTITYIDRESPONSE._serialized_start = 3881
    _FINDPATHINCLUDINGSOURCEBYENTITYIDRESPONSE._serialized_end = 3940
    _FINDPATHINCLUDINGSOURCEBYENTITYID_V2REQUEST._serialized_start = 3943
    _FINDPATHINCLUDINGSOURCEBYENTITYID_V2REQUEST._serialized_end = 4109
    _FINDPATHINCLUDINGSOURCEBYENTITYID_V2RESPONSE._serialized_start = 4111
    _FINDPATHINCLUDINGSOURCEBYENTITYID_V2RESPONSE._serialized_end = 4173
    _FINDPATHINCLUDINGSOURCEBYRECORDIDREQUEST._serialized_start = 4176
    _FINDPATHINCLUDINGSOURCEBYRECORDIDREQUEST._serialized_end = 4373
    _FINDPATHINCLUDINGSOURCEBYRECORDIDRESPONSE._serialized_start = 4375
    _FINDPATHINCLUDINGSOURCEBYRECORDIDRESPONSE._serialized_end = 4434
    _FINDPATHINCLUDINGSOURCEBYRECORDID_V2REQUEST._serialized_start = 4437
    _FINDPATHINCLUDINGSOURCEBYRECORDID_V2REQUEST._serialized_end = 4652
    _FINDPATHINCLUDINGSOURCEBYRECORDID_V2RESPONSE._serialized_start = 4654
    _FINDPATHINCLUDINGSOURCEBYRECORDID_V2RESPONSE._serialized_end = 4716
    _GETACTIVECONFIGIDREQUEST._serialized_start = 4718
    _GETACTIVECONFIGIDREQUEST._serialized_end = 4744
    _GETACTIVECONFIGIDRESPONSE._serialized_start = 4746
    _GETACTIVECONFIGIDRESPONSE._serialized_end = 4789
    _GETENTITYBYENTITYIDREQUEST._serialized_start = 4791
    _GETENTITYBYENTITYIDREQUEST._serialized_end = 4837
    _GETENTITYBYENTITYIDRESPONSE._serialized_start = 4839
    _GETENTITYBYENTITYIDRESPONSE._serialized_end = 4884
    _GETENTITYBYENTITYID_V2REQUEST._serialized_start = 4886
    _GETENTITYBYENTITYID_V2REQUEST._serialized_end = 4950
    _GETENTITYBYENTITYID_V2RESPONSE._serialized_start = 4952
    _GETENTITYBYENTITYID_V2RESPONSE._serialized_end = 5000
    _GETENTITYBYRECORDIDREQUEST._serialized_start = 5002
    _GETENTITYBYRECORDIDREQUEST._serialized_end = 5072
    _GETENTITYBYRECORDIDRESPONSE._serialized_start = 5074
    _GETENTITYBYRECORDIDRESPONSE._serialized_end = 5119
    _GETENTITYBYRECORDID_V2REQUEST._serialized_start = 5121
    _GETENTITYBYRECORDID_V2REQUEST._serialized_end = 5209
    _GETENTITYBYRECORDID_V2RESPONSE._serialized_start = 5211
    _GETENTITYBYRECORDID_V2RESPONSE._serialized_end = 5259
    _GETRECORDREQUEST._serialized_start = 5261
    _GETRECORDREQUEST._serialized_end = 5321
    _GETRECORDRESPONSE._serialized_start = 5323
    _GETRECORDRESPONSE._serialized_end = 5358
    _GETRECORD_V2REQUEST._serialized_start = 5360
    _GETRECORD_V2REQUEST._serialized_end = 5438
    _GETRECORD_V2RESPONSE._serialized_start = 5440
    _GETRECORD_V2RESPONSE._serialized_end = 5478
    _GETREDORECORDREQUEST._serialized_start = 5480
    _GETREDORECORDREQUEST._serialized_end = 5502
    _GETREDORECORDRESPONSE._serialized_start = 5504
    _GETREDORECORDRESPONSE._serialized_end = 5543
    _GETREPOSITORYLASTMODIFIEDTIMEREQUEST._serialized_start = 5545
    _GETREPOSITORYLASTMODIFIEDTIMEREQUEST._serialized_end = 5583
    _GETREPOSITORYLASTMODIFIEDTIMERESPONSE._serialized_start = 5585
    _GETREPOSITORYLASTMODIFIEDTIMERESPONSE._serialized_end = 5640
    _GETVIRTUALENTITYBYRECORDIDREQUEST._serialized_start = 5642
    _GETVIRTUALENTITYBYRECORDIDREQUEST._serialized_end = 5697
    _GETVIRTUALENTITYBYRECORDIDRESPONSE._serialized_start = 5699
    _GETVIRTUALENTITYBYRECORDIDRESPONSE._serialized_end = 5751
    _GETVIRTUALENTITYBYRECORDID_V2REQUEST._serialized_start = 5753
    _GETVIRTUALENTITYBYRECORDID_V2REQUEST._serialized_end = 5826
    _GETVIRTUALENTITYBYRECORDID_V2RESPONSE._serialized_start = 5828
    _GETVIRTUALENTITYBYRECORDID_V2RESPONSE._serialized_end = 5883
    _HOWENTITYBYENTITYIDREQUEST._serialized_start = 5885
    _HOWENTITYBYENTITYIDREQUEST._serialized_end = 5931
    _HOWENTITYBYENTITYIDRESPONSE._serialized_start = 5933
    _HOWENTITYBYENTITYIDRESPONSE._serialized_end = 5978
    _HOWENTITYBYENTITYID_V2REQUEST._serialized_start = 5980
    _HOWENTITYBYENTITYID_V2REQUEST._serialized_end = 6044
    _HOWENTITYBYENTITYID_V2RESPONSE._serialized_start = 6046
    _HOWENTITYBYENTITYID_V2RESPONSE._serialized_end = 6094
    _INITREQUEST._serialized_start = 6096
    _INITREQUEST._serialized_end = 6172
    _INITRESPONSE._serialized_start = 6174
    _INITRESPONSE._serialized_end = 6188
    _INITWITHCONFIGIDREQUEST._serialized_start = 6190
    _INITWITHCONFIGIDREQUEST._serialized_end = 6300
    _INITWITHCONFIGIDRESPONSE._serialized_start = 6302
    _INITWITHCONFIGIDRESPONSE._serialized_end = 6328
    _PRIMEENGINEREQUEST._serialized_start = 6330
    _PRIMEENGINEREQUEST._serialized_end = 6350
    _PRIMEENGINERESPONSE._serialized_start = 6352
    _PRIMEENGINERESPONSE._serialized_end = 6373
    _PROCESSREQUEST._serialized_start = 6375
    _PROCESSREQUEST._serialized_end = 6407
    _PROCESSRESPONSE._serialized_start = 6409
    _PROCESSRESPONSE._serialized_end = 6426
    _PROCESSWITHINFOREQUEST._serialized_start = 6428
    _PROCESSWITHINFOREQUEST._serialized_end = 6483
    _PROCESSWITHINFORESPONSE._serialized_start = 6485
    _PROCESSWITHINFORESPONSE._serialized_end = 6526
    _PURGEREPOSITORYREQUEST._serialized_start = 6528
    _PURGEREPOSITORYREQUEST._serialized_end = 6552
    _PURGEREPOSITORYRESPONSE._serialized_start = 6554
    _PURGEREPOSITORYRESPONSE._serialized_end = 6579
    _REEVALUATEENTITYREQUEST._serialized_start = 6581
    _REEVALUATEENTITYREQUEST._serialized_end = 6639
    _REEVALUATEENTITYRESPONSE._serialized_start = 6641
    _REEVALUATEENTITYRESPONSE._serialized_end = 6667
    _REEVALUATEENTITYWITHINFOREQUEST._serialized_start = 6669
    _REEVALUATEENTITYWITHINFOREQUEST._serialized_end = 6735
    _REEVALUATEENTITYWITHINFORESPONSE._serialized_start = 6737
    _REEVALUATEENTITYWITHINFORESPONSE._serialized_end = 6787
    _REEVALUATERECORDREQUEST._serialized_start = 6789
    _REEVALUATERECORDREQUEST._serialized_end = 6871
    _REEVALUATERECORDRESPONSE._serialized_start = 6873
    _REEVALUATERECORDRESPONSE._serialized_end = 6899
    _REEVALUATERECORDWITHINFOREQUEST._serialized_start = 6901
    _REEVALUATERECORDWITHINFOREQUEST._serialized_end = 6991
    _REEVALUATERECORDWITHINFORESPONSE._serialized_start = 6993
    _REEVALUATERECORDWITHINFORESPONSE._serialized_end = 7043
    _REINITREQUEST._serialized_start = 7045
    _REINITREQUEST._serialized_end = 7082
    _REINITRESPONSE._serialized_start = 7084
    _REINITRESPONSE._serialized_end = 7100
    _REPLACERECORDREQUEST._serialized_start = 7102
    _REPLACERECORDREQUEST._serialized_end = 7200
    _REPLACERECORDRESPONSE._serialized_start = 7202
    _REPLACERECORDRESPONSE._serialized_end = 7225
    _REPLACERECORDWITHINFOREQUEST._serialized_start = 7227
    _REPLACERECORDWITHINFOREQUEST._serialized_end = 7348
    _REPLACERECORDWITHINFORESPONSE._serialized_start = 7350
    _REPLACERECORDWITHINFORESPONSE._serialized_end = 7397
    _SEARCHBYATTRIBUTESREQUEST._serialized_start = 7399
    _SEARCHBYATTRIBUTESREQUEST._serialized_end = 7444
    _SEARCHBYATTRIBUTESRESPONSE._serialized_start = 7446
    _SEARCHBYATTRIBUTESRESPONSE._serialized_end = 7490
    _SEARCHBYATTRIBUTES_V2REQUEST._serialized_start = 7492
    _SEARCHBYATTRIBUTES_V2REQUEST._serialized_end = 7555
    _SEARCHBYATTRIBUTES_V2RESPONSE._serialized_start = 7557
    _SEARCHBYATTRIBUTES_V2RESPONSE._serialized_end = 7604
    _STATSREQUEST._serialized_start = 7606
    _STATSREQUEST._serialized_end = 7620
    _STATSRESPONSE._serialized_start = 7622
    _STATSRESPONSE._serialized_end = 7653
    _STREAMEXPORTCSVENTITYREPORTREQUEST._serialized_start = 7655
    _STREAMEXPORTCSVENTITYREPORTREQUEST._serialized_end = 7729
    _STREAMEXPORTCSVENTITYREPORTRESPONSE._serialized_start = 7731
    _STREAMEXPORTCSVENTITYREPORTRESPONSE._serialized_end = 7784
    _STREAMEXPORTJSONENTITYREPORTREQUEST._serialized_start = 7786
    _STREAMEXPORTJSONENTITYREPORTREQUEST._serialized_end = 7838
    _STREAMEXPORTJSONENTITYREPORTRESPONSE._serialized_start = 7840
    _STREAMEXPORTJSONENTITYREPORTRESPONSE._serialized_end = 7894
    _WHYENTITIESREQUEST._serialized_start = 7896
    _WHYENTITIESREQUEST._serialized_end = 7954
    _WHYENTITIESRESPONSE._serialized_start = 7956
    _WHYENTITIESRESPONSE._serialized_end = 7993
    _WHYENTITIES_V2REQUEST._serialized_start = 7995
    _WHYENTITIES_V2REQUEST._serialized_end = 8071
    _WHYENTITIES_V2RESPONSE._serialized_start = 8073
    _WHYENTITIES_V2RESPONSE._serialized_end = 8113
    _WHYENTITYBYENTITYIDREQUEST._serialized_start = 8115
    _WHYENTITYBYENTITYIDREQUEST._serialized_end = 8161
    _WHYENTITYBYENTITYIDRESPONSE._serialized_start = 8163
    _WHYENTITYBYENTITYIDRESPONSE._serialized_end = 8208
    _WHYENTITYBYENTITYID_V2REQUEST._serialized_start = 8210
    _WHYENTITYBYENTITYID_V2REQUEST._serialized_end = 8274
    _WHYENTITYBYENTITYID_V2RESPONSE._serialized_start = 8276
    _WHYENTITYBYENTITYID_V2RESPONSE._serialized_end = 8324
    _WHYENTITYBYRECORDIDREQUEST._serialized_start = 8326
    _WHYENTITYBYRECORDIDREQUEST._serialized_end = 8396
    _WHYENTITYBYRECORDIDRESPONSE._serialized_start = 8398
    _WHYENTITYBYRECORDIDRESPONSE._serialized_end = 8443
    _WHYENTITYBYRECORDID_V2REQUEST._serialized_start = 8445
    _WHYENTITYBYRECORDID_V2REQUEST._serialized_end = 8533
    _WHYENTITYBYRECORDID_V2RESPONSE._serialized_start = 8535
    _WHYENTITYBYRECORDID_V2RESPONSE._serialized_end = 8583
    _WHYRECORDSREQUEST._serialized_start = 8585
    _WHYRECORDSREQUEST._serialized_end = 8692
    _WHYRECORDSRESPONSE._serialized_start = 8694
    _WHYRECORDSRESPONSE._serialized_end = 8730
    _WHYRECORDS_V2REQUEST._serialized_start = 8732
    _WHYRECORDS_V2REQUEST._serialized_end = 8857
    _WHYRECORDS_V2RESPONSE._serialized_start = 8859
    _WHYRECORDS_V2RESPONSE._serialized_end = 8898
    _G2ENGINE._serialized_start = 8901
    _G2ENGINE._serialized_end = 16051
# @@protoc_insertion_point(module_scope)
